camelot.camelot.model.authentication.SupplierCustomer

Package camelot :: Package camelot :: Package model :: Module authentication :: Class SupplierCustomer |
[hide private]
[frames] | no frames]

# Class SupplierCustomer

source code

Relation from supplier to customer

Nested Classes | [hide private]
| CustomerAdmin
| SupplierAdmin

Class Variables | [hide private]
| established_from = `ManyToOne('Party', required= True, ondelete`...``
| established_to = `ManyToOne('Party', required= True, ondelete= `...``
Inherited from `PartyRelationship`: `comment`, `from_date`, `thru_date`

Class Variable Details | [hide private]

  ### established_from Value:
      ManyToOne('Party', required= True, ondelete= 'cascade', onupdate= 'cas
      cade')

  ### established_to Value:
      ManyToOne('Party', required= True, ondelete= 'cascade', onupdate= 'cas
      cade')